@@ -22,6 +22,8 @@ def url_to_module(url):
         'acfun': acfun,
         'bilibili': bilibili,
         'cntv': cntv,
+        'dailymotion': dailymotion,
+        'google': googleplus,
         'iask': sina,
         'ifeng': ifeng,
         'iqiyi': iqiyi,
